JBoss Tools SVN: r40040 - trunk/esb/tests/org.jboss.tools.esb.ui.bot.test/src/org/jboss/tools/esb/ui/bot/tests/examples.
by jbosstools-commits@lists.jboss.org
Author: ldimaggio
Date: 2012-04-04 14:13:23 -0400 (Wed, 04 Apr 2012)
New Revision: 40040
Modified:
trunk/esb/tests/org.jboss.tools.esb.ui.bot.test/src/org/jboss/tools/esb/ui/bot/tests/examples/SimpleEAPTest.java
Log:
Added more tests for EAP/JBDS integration
Modified: trunk/esb/tests/org.jboss.tools.esb.ui.bot.test/src/org/jboss/tools/esb/ui/bot/tests/examples/SimpleEAPTest.java
===================================================================
--- trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/JcrUiConstants.java 2012-04-04 14:58:29 UTC (rev 40038)
+++ trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/JcrUiConstants.java 2012-04-04 16:11:17 UTC (rev 40039)
@@ -7,7 +7,6 @@
*/
package org.jboss.tools.modeshape.jcr.ui;
-
/**
* Constants used within the <code>org.jboss.tools.modeshape.jcr.ui</code> plug-in.
*/
@@ -71,6 +70,12 @@
String CND_EDITOR = ICONS_FOLDER + "cnd-editor-16x.png"; //$NON-NLS-1$
/**
+ * The relative path from the plugin folder to the icon used to select the declaring node type definition of an inherited
+ * property definition or child node definition.
+ */
+ String OPEN_DECLARING_NODE_TYPE = ICONS_FOLDER + "open-declaring-node-type-16x.gif"; //$NON-NLS-1$
+
+ /**
* The relative path from the plugin folder to the icon used to show inherited properties and child nodes.
*/
String SHOW_INHERITED = ICONS_FOLDER + "show-inherited-16x.gif"; //$NON-NLS-1$
Modified: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndFormsEditorPage.java
===================================================================
--- trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndFormsEditorPage.java 2012-04-04 14:58:29 UTC (rev 40038)
+++ trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndFormsEditorPage.java 2012-04-04 16:11:17 UTC (rev 40039)
@@ -126,6 +126,8 @@
private String nodeTypeNameFilterPattern;
private Section nodeTypeSection;
private TableViewer nodeTypeViewer;
+ private IAction openChildNodeDeclaringNodeType;
+ private IAction openPropertyDeclaringNodeType;
private Section propertiesSection;
private TableViewer propertyViewer;
private NodeTypeDefinition selectedNodeType; // needed for property changes (can be null)
@@ -227,6 +229,23 @@
this.showInheritedChildNodes.setToolTipText(CndMessages.showInheritedChildNodesToolTip);
this.showInheritedChildNodes.setImageDescriptor(Activator.getSharedInstance()
.getImageDescriptor(JcrUiConstants.Images.SHOW_INHERITED));
+
+ this.openChildNodeDeclaringNodeType = new Action(Utils.EMPTY_STRING) {
+
+ /**
+ * {@inheritDoc}
+ *
+ * @see org.eclipse.jface.action.Action#run()
+ */
+ @Override
+ public void run() {
+ handleSelectPropertyDeclaringNodeType();
+ }
+ };
+ this.openChildNodeDeclaringNodeType.setEnabled(false);
+ this.openChildNodeDeclaringNodeType.setToolTipText(CndMessages.openDeclaringNodeTypeToolTip);
+ this.openChildNodeDeclaringNodeType.setImageDescriptor(Activator.getSharedInstance()
+ .getImageDescriptor(JcrUiConstants.Images.OPEN_DECLARING_NODE_TYPE));
}
private void createChildNodeSection( final IManagedForm managedForm,
@@ -262,7 +281,7 @@
// create toolbar
FormUtils.createToolBar(container, toolkit, new IAction[] { this.addChildNode, this.editChildNode, this.deleteChildNode,
- this.showInheritedChildNodes });
+ this.showInheritedChildNodes, this.openChildNodeDeclaringNodeType });
final Table table = FormUtils.createTable(toolkit, container);
((GridData)table.getLayoutData()).heightHint = table.getItemHeight() * 5;
@@ -272,6 +291,7 @@
menuManager.add(new DelegateAction(CndMessages.addChildNodeMenuText, this.addChildNode));
menuManager.add(new DelegateAction(CndMessages.editChildNodeMenuText, this.editChildNode));
menuManager.add(new DelegateAction(CndMessages.deleteChildNodeMenuText, this.deleteChildNode));
+ menuManager.add(new DelegateAction(CndMessages.openDeclaringNodeTypeMenuText, this.openChildNodeDeclaringNodeType));
table.setMenu(menuManager.createContextMenu(table));
createChildNodeViewer(table);
@@ -299,7 +319,7 @@
if (shouldShowInheritedChildNodes()) {
final NodeTypeDefinition nodeTypeDefinition = getSelectedNodeType();
- if (Utils.equivalent(nodeTypeDefinition.getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
+ if (!Utils.equivalent(nodeTypeDefinition.getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
.get())) {
return getShell().getDisplay().getSystemColor(SWT.COLOR_WIDGET_LIGHT_SHADOW);
}
@@ -320,7 +340,7 @@
if (shouldShowInheritedChildNodes()) {
final NodeTypeDefinition nodeTypeDefinition = getSelectedNodeType();
- if (Utils.equivalent(nodeTypeDefinition.getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
+ if (!Utils.equivalent(nodeTypeDefinition.getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
.get())) {
return JFaceResources.getFontRegistry().getItalic(JFaceResources.TEXT_FONT);
}
@@ -345,7 +365,7 @@
final NotationType notationType = NotationType.LONG;
if (this.columnIndex == ChildNodeColumnIndexes.DECLARING_NODE_TYPE) {
- if (Utils.equivalent(getSelectedNodeType().getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
+ if (!Utils.equivalent(getSelectedNodeType().getName(), childNodeDefinition.getDeclaringNodeTypeDefinitionName()
.get())) {
return childNodeDefinition.getDeclaringNodeTypeDefinitionName().get();
}
@@ -560,7 +580,6 @@
toolkit.paintBordersFor(attributesContainer);
this.btnAbstract = toolkit.createButton(attributesContainer, CndMessages.abstractAttribute, SWT.CHECK);
- this.btnAbstract.setBackground(attributesContainer.getBackground());
this.btnAbstract.addSelectionListener(new SelectionAdapter() {
/**
@@ -576,7 +595,6 @@
this.btnAbstract.setToolTipText(CndMessages.abstractAttributeToolTip);
this.btnMixin = toolkit.createButton(attributesContainer, CndMessages.mixinAttribute, SWT.CHECK);
- this.btnMixin.setBackground(attributesContainer.getBackground());
this.btnMixin.addSelectionListener(new SelectionAdapter() {
/**
@@ -592,7 +610,6 @@
this.btnMixin.setToolTipText(CndMessages.mixinAttributeToolTip);
this.btnOrderable = toolkit.createButton(attributesContainer, CndMessages.orderableAttribute, SWT.CHECK);
- this.btnOrderable.setBackground(attributesContainer.getBackground());
this.btnOrderable.addSelectionListener(new SelectionAdapter() {
/**
@@ -608,7 +625,6 @@
this.btnOrderable.setToolTipText(CndMessages.orderableAttributeToolTip);
this.btnQueryable = toolkit.createButton(attributesContainer, CndMessages.queryableAttribute, SWT.CHECK);
- this.btnQueryable.setBackground(attributesContainer.getBackground());
this.btnQueryable.addSelectionListener(new SelectionAdapter() {
/**
@@ -1237,6 +1253,23 @@
this.showInheritedProperties.setToolTipText(CndMessages.showInheritedPropertiesToolTip);
this.showInheritedProperties.setImageDescriptor(Activator.getSharedInstance()
.getImageDescriptor(JcrUiConstants.Images.SHOW_INHERITED));
+
+ this.openPropertyDeclaringNodeType = new Action(Utils.EMPTY_STRING) {
+
+ /**
+ * {@inheritDoc}
+ *
+ * @see org.eclipse.jface.action.Action#run()
+ */
+ @Override
+ public void run() {
+ handleSelectPropertyDeclaringNodeType();
+ }
+ };
+ this.openPropertyDeclaringNodeType.setEnabled(false);
+ this.openPropertyDeclaringNodeType.setToolTipText(CndMessages.openDeclaringNodeTypeToolTip);
+ this.openPropertyDeclaringNodeType.setImageDescriptor(Activator.getSharedInstance()
+ .getImageDescriptor(JcrUiConstants.Images.OPEN_DECLARING_NODE_TYPE));
}
private void createPropertySection( final IManagedForm managedForm,
@@ -1272,7 +1305,7 @@
// create toolbar
FormUtils.createToolBar(container, toolkit, new IAction[] { this.addProperty, this.editProperty, this.deleteProperty,
- this.showInheritedProperties });
+ this.showInheritedProperties, this.openPropertyDeclaringNodeType });
final Table table = FormUtils.createTable(toolkit, container);
((GridData)table.getLayoutData()).heightHint = table.getItemHeight() * 5;
@@ -1282,6 +1315,7 @@
menuManager.add(new DelegateAction(CndMessages.addPropertyMenuText, this.addProperty));
menuManager.add(new DelegateAction(CndMessages.editPropertyMenuText, this.editProperty));
menuManager.add(new DelegateAction(CndMessages.deletePropertyMenuText, this.deleteProperty));
+ menuManager.add(new DelegateAction(CndMessages.openDeclaringNodeTypeMenuText, this.openPropertyDeclaringNodeType));
table.setMenu(menuManager.createContextMenu(table));
createPropertyViewer(table);
@@ -1956,19 +1990,25 @@
this.addChildNode.setEnabled(enable);
}
- enable = (getSelectedChildNode() != null);
+ boolean enableWithChildNodeSelected = (enable && (getSelectedChildNode() != null));
+ boolean enableInheritedChildNode = enableWithChildNodeSelected
+ && !getSelectedNodeType().hasDeclaredChildNodeDefinition(getSelectedChildNode().getName());
+ boolean enableDeclaredChildNode = enableWithChildNodeSelected
+ && getSelectedNodeType().hasDeclaredChildNodeDefinition(getSelectedChildNode().getName());
- // disable if selected child node is inherited
- if (enable && shouldShowInheritedChildNodes()) {
- enable = getSelectedNodeType().hasDeclaredChildNodeDefinition(getSelectedChildNode().getName());
+ // enable if selected child node is not inherited
+ if (this.editChildNode.isEnabled() != enableDeclaredChildNode) {
+ this.editChildNode.setEnabled(enableDeclaredChildNode);
}
- if (this.editChildNode.isEnabled() != enable) {
- this.editChildNode.setEnabled(enable);
+ // enable if selected child node is not inherited
+ if (this.deleteChildNode.isEnabled() != enableDeclaredChildNode) {
+ this.deleteChildNode.setEnabled(enableDeclaredChildNode);
}
- if (this.deleteChildNode.isEnabled() != enable) {
- this.deleteChildNode.setEnabled(enable);
+ // enable if selected child node is inherited
+ if (this.openChildNodeDeclaringNodeType.isEnabled() != enableInheritedChildNode) {
+ this.openChildNodeDeclaringNodeType.setEnabled(enableInheritedChildNode);
}
}
@@ -2390,19 +2430,25 @@
this.addProperty.setEnabled(enable);
}
- enable = (getSelectedProperty() != null);
+ boolean enableWithPropertySelected = (enable && (getSelectedProperty() != null));
+ boolean enableInheritedProperty = enableWithPropertySelected
+ && !getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
+ boolean enableDeclaredProperty = enableWithPropertySelected
+ && getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
- // disable if selected property is inherited
- if (enable && shouldShowInheritedProperties()) {
- enable = getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
+ // enable if selected property is not inherited
+ if (this.editProperty.isEnabled() != enableDeclaredProperty) {
+ this.editProperty.setEnabled(enableDeclaredProperty);
}
- if (this.editProperty.isEnabled() != enable) {
- this.editProperty.setEnabled(enable);
+ // enable if selected property is not inherited
+ if (this.deleteProperty.isEnabled() != enableDeclaredProperty) {
+ this.deleteProperty.setEnabled(enableDeclaredProperty);
}
- if (this.deleteProperty.isEnabled() != enable) {
- this.deleteProperty.setEnabled(enable);
+ // enable if selected property is inherited
+ if (this.openPropertyDeclaringNodeType.isEnabled() != enableInheritedProperty) {
+ this.openPropertyDeclaringNodeType.setEnabled(enableInheritedProperty);
}
}
@@ -2410,6 +2456,18 @@
getSelectedNodeType().setQueryable(newValue);
}
+ void handleSelectPropertyDeclaringNodeType() {
+ assert (getSelectedProperty() != null) : "handleSelectPropertyDeclaringNodeType called and no property selected"; //$NON-NLS-1$
+ QualifiedName qname = getSelectedProperty().getDeclaringNodeTypeDefinitionName();
+ NodeTypeDefinition nodeType = getCnd().getNodeTypeDefinition(qname.get());
+
+ if (nodeType == null) {
+
+ } else {
+ this.nodeTypeViewer.setSelection(new StructuredSelection(nodeType));
+ }
+ }
+
void handleShowInheritedChildNodesChanged() {
refreshChildNodeViewer();
}
@@ -2800,19 +2858,25 @@
this.propertyViewer.getTable().setEnabled(enableWithNodeTypeSelected);
}
- boolean enable = (enableWithNodeTypeSelected && (getSelectedProperty() != null));
+ boolean enableWithPropertySelected = (enableWithNodeTypeSelected && (getSelectedProperty() != null));
+ boolean enableInheritedProperty = enableWithPropertySelected
+ && !getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
+ boolean enableDeclaredProperty = enableWithPropertySelected
+ && getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
- // disable if selected property is inherited
- if (enable && shouldShowInheritedProperties()) {
- enable = getSelectedNodeType().hasDeclaredPropertyDefinition(getSelectedProperty().getName());
+ // enable if selected property is not inherited
+ if (this.editProperty.isEnabled() != enableDeclaredProperty) {
+ this.editProperty.setEnabled(enableDeclaredProperty);
}
- if (this.editProperty.isEnabled() != enable) {
- this.editProperty.setEnabled(enable);
+ // enable if selected property is not inherited
+ if (this.deleteProperty.isEnabled() != enableDeclaredProperty) {
+ this.deleteProperty.setEnabled(enableDeclaredProperty);
}
- if (this.deleteProperty.isEnabled() != enable) {
- this.deleteProperty.setEnabled(enable);
+ // enable if selected property is inherited
+ if (this.openPropertyDeclaringNodeType.isEnabled() != enableInheritedProperty) {
+ this.openPropertyDeclaringNodeType.setEnabled(enableInheritedProperty);
}
}
Modified: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndMessages.java
===================================================================
--- trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndMessages.java 2012-04-04 14:58:29 UTC (rev 40038)
+++ trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndMessages.java 2012-04-04 16:11:17 UTC (rev 40039)
@@ -971,6 +971,16 @@
public static String onParentVersionToolTip;
/**
+ * The context menu item text for the open declaring node type action.
+ */
+ public static String openDeclaringNodeTypeMenuText;
+
+ /**
+ * A tool tip message of the open declaring node type action.
+ */
+ public static String openDeclaringNodeTypeToolTip;
+
+ /**
* A name for the orderable attribute suitable for a radio or check button.
*/
public static String orderableAttribute;
Modified: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/cndMessages.properties
===================================================================
--- trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/cndMessages.properties 2012-04-04 14:58:29 UTC (rev 40038)
+++ trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/cndMessages.properties 2012-04-04 16:11:17 UTC (rev 40039)
@@ -200,6 +200,8 @@
notEqualsOperatorToolTip = Indicates if the property supports the "not equals" query operation
onParentVersionLabel = On Parent Version:
onParentVersionToolTip = Indicates what happens to the child node/property when the parent is created
+openDeclaringNodeTypeMenuText = Open Declaring Node Type
+openDeclaringNodeTypeToolTip = Open the declaring node type in the editor if that node type is in the CND being edited
orderableAttribute = Orderable
orderableAttributeToolTip = Indicates if the node type definition's are ordered
primaryItemLabel = Primary Item:
14 years
JBoss Tools SVN: r40038 - trunk/tests/plugins/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext.
by jbosstools-commits@lists.jboss.org
Author: jgargula
Date: 2012-04-04 10:58:29 -0400 (Wed, 04 Apr 2012)
New Revision: 40038
Modified:
trunk/tests/plugins/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTBotExt.java
Log:
Improved method waitForNumberOfShells - waits just for opened shells.
Modified: trunk/tests/plugins/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTBotExt.java
===================================================================
--- trunk/tests/plugins/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTBotExt.java 2012-04-04 14:20:15 UTC (rev 40037)
+++ trunk/tests/plugins/org.jboss.tools.ui.bot.ext/src/org/jboss/tools/ui/bot/ext/SWTBotExt.java 2012-04-04 14:58:29 UTC (rev 40038)
@@ -257,7 +257,7 @@
}
/**
- * Waits until there is desired number of shells.
+ * Waits until there is desired number of opened shells.
* It is useful sometimes when you cannot address exactly
* what you are waiting for but you know that the right situation
* is when there is <code>desiredNumberOfSheels</code> of shells.
@@ -270,19 +270,27 @@
* @return Shells which exists after timeout or after achieving desired
* number of shells.
*/
- public SWTBotShell[] waitForNumberOfShells(final int desiredNumberOfShells, final int maxTimeout) {
+ public List<SWTBotShell> waitForNumberOfShells(final int desiredNumberOfShells, final int maxTimeout) {
final int SLEEP_TIME = Timing.time2S();
final int ATTEMPTS_TIMEOUT = getAttemptsTimeout((maxTimeout < 0 ? 30 : maxTimeout), SLEEP_TIME);
+ List<SWTBotShell> shells = null;
for (int i = 0; i < ATTEMPTS_TIMEOUT; i++) {
- if (shells().length != desiredNumberOfShells) {
+ SWTBotShell[] shellsArray = shells();
+ shells = new ArrayList<SWTBotShell>(shellsArray.length);
+ for (int j = 0; j < shellsArray.length; j++) {
+ if (shellsArray[j].isOpen()) {
+ shells.add(shellsArray[j]);
+ }
+ }
+ if (shells.size() != desiredNumberOfShells) {
sleep(SLEEP_TIME);
} else {
break;
}
}
- return shells();
+ return shells;
}
/**
@@ -293,7 +301,7 @@
* @return Shells which exists after timeout or after achieving desired
* number of shells.
*/
- public SWTBotShell[] waitForNumberOfShells(final int desiredNumberOfShells) {
+ public List<SWTBotShell> waitForNumberOfShells(final int desiredNumberOfShells) {
return waitForNumberOfShells(desiredNumberOfShells, -1);
}
14 years
JBoss Tools SVN: r40037 - in trunk/vpe: plugins/org.jboss.tools.vpe.browsersim.eclipse/META-INF and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-04-04 10:20:15 -0400 (Wed, 04 Apr 2012)
New Revision: 40037
Modified:
trunk/vpe/features/org.jboss.tools.vpe.browsersim.feature/feature.xml
trunk/vpe/plugins/org.jboss.tools.vpe.browsersim.eclipse/META-INF/MANIFEST.MF
Log:
revert JBIDE11047.patch.platform.filter.manifest.mf.and.feature.xml.txt for JBIDE-11047 pending Yahor's fix to make UI state it doesn't work on Win64
Modified: trunk/vpe/features/org.jboss.tools.vpe.browsersim.feature/feature.xml
===================================================================
--- trunk/vpe/features/org.jboss.tools.vpe.browsersim.feature/feature.xml 2012-04-04 14:02:24 UTC (rev 40036)
+++ trunk/vpe/features/org.jboss.tools.vpe.browsersim.feature/feature.xml 2012-04-04 14:20:15 UTC (rev 40037)
@@ -15,8 +15,5 @@
<plugin id="org.jboss.tools.vpe.browsersim" download-size="0" install-size="0" version="0.0.0" unpack="false" />
<plugin id="org.jboss.tools.vpe.browsersim.browser" download-size="0" install-size="0" version="0.0.0" unpack="false" />
-
- <plugin id="org.jboss.tools.vpe.browsersim.eclipse" arch="x86" download-size="0" install-size="0" version="0.0.0" unpack="false" />
- <plugin id="org.jboss.tools.vpe.browsersim.eclipse" os="linux,macosx" arch="x86_64" download-size="0" install-size="0" version="0.0.0" unpack="false" />
-
+ <plugin id="org.jboss.tools.vpe.browsersim.eclipse" download-size="0" install-size="0" version="0.0.0" unpack="false"/>
</feature>
Modified: trunk/vpe/plugins/org.jboss.tools.vpe.browsersim.eclipse/META-INF/MANIFEST.MF
===================================================================
--- trunk/vpe/plugins/org.jboss.tools.vpe.browsersim.eclipse/META-INF/MANIFEST.MF 2012-04-04 14:02:24 UTC (rev 40036)
+++ trunk/vpe/plugins/org.jboss.tools.vpe.browsersim.eclipse/META-INF/MANIFEST.MF 2012-04-04 14:20:15 UTC (rev 40037)
@@ -21,8 +21,3 @@
Bundle-ActivationPolicy: lazy
Bundle-RequiredExecutionEnvironment: JavaSE-1.6
Bundle-Vendor: JBoss by Red Hat
-Eclipse-PlatformFilter: (|
- (&(osgi.ws=win32)(osgi.os=win32)(osgi.arch=x86))
- (&(osgi.ws=cocoa)(osgi.os=macosx) (|(osgi.arch=x86)(osgi.arch=x86_64)) )
- (&(osgi.ws=gtk)(osgi.os=linux) (|(osgi.arch=x86)(osgi.arch=x86_64)) )
- )
14 years
JBoss Tools SVN: r40035 - in trunk/hibernatetools/plugins: org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: dgeraskov
Date: 2012-04-04 10:00:46 -0400 (Wed, 04 Apr 2012)
New Revision: 40035
Modified:
trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java
trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java
Log:
https://issues.jboss.org/browse/JBIDE-11467
File path could be either absolute to file system or relative to project class path
Modified: trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java
===================================================================
--- trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java 2012-04-04 13:39:36 UTC (rev 40034)
+++ trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.core/src/org/jboss/tools/hibernate/jpt/core/internal/context/HibernatePersistenceUnit.java 2012-04-04 14:00:46 UTC (rev 40035)
@@ -21,7 +21,6 @@
import org.eclipse.core.resources.IContainer;
import org.eclipse.core.resources.IResource;
-import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.core.runtime.Path;
import org.eclipse.jdt.core.IJavaProject;
@@ -295,7 +294,26 @@
HibernateJptPlugin.logException(e);
}
- IResource res= ResourcesPlugin.getWorkspace().getRoot().findMember(path);
+ IJavaProject jProject = getJpaProject().getJavaProject();
+ IResource res = null;
+ if (jProject != null){
+ try {
+ IPackageFragmentRoot[] allPackageFragmentRoots = jProject.getAllPackageFragmentRoots();
+ for (IPackageFragmentRoot iPackageFragmentRoot : allPackageFragmentRoots) {
+ if (!iPackageFragmentRoot.isArchive()){
+ IResource sourceFolder = iPackageFragmentRoot.getResource();
+ if (sourceFolder instanceof IContainer) {
+ IContainer folder = (IContainer) sourceFolder;
+ if ((res = folder.findMember(path)) != null){
+ break;
+ }
+ }
+ }
+ }
+ } catch (JavaModelException e) {
+ //ignore
+ }
+ }
if (res != null) {
int resType= res.getType();
if (resType != IResource.FILE) {
Modified: trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java
===================================================================
--- trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java 2012-04-04 13:39:36 UTC (rev 40034)
+++ trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java 2012-04-04 14:00:46 UTC (rev 40035)
@@ -254,8 +254,7 @@
IResource res = root.findMember(cfgFile);
if ( res != null && res.exists() && res.getType() == IResource.FILE) {
JpaProject jpaProject = HibernatePropertiesComposite.this.getSubject().getJpaProject();
- IProject project = jpaProject.getProject();
- IJavaProject jProject = JavaCore.create(project);
+ IJavaProject jProject = jpaProject.getJavaProject();
if (jProject != null){
try {
IPackageFragmentRoot[] allPackageFragmentRoots = jProject.getAllPackageFragmentRoots();
14 years
JBoss Tools SVN: r40034 - trunk/runtime-soa/tests/org.jboss.tools.runtime.soa.test.
by jbosstools-commits@lists.jboss.org
Author: mickael_istria
Date: 2012-04-04 09:39:36 -0400 (Wed, 04 Apr 2012)
New Revision: 40034
Modified:
trunk/runtime-soa/tests/org.jboss.tools.runtime.soa.test/pom.xml
Log:
JBIDE-11370:
Fix pom for runtime.soa.tests
Modified: trunk/runtime-soa/tests/org.jboss.tools.runtime.soa.test/pom.xml
===================================================================
--- trunk/runtime-soa/tests/org.jboss.tools.runtime.soa.test/pom.xml 2012-04-04 13:21:43 UTC (rev 40033)
+++ trunk/runtime-soa/tests/org.jboss.tools.runtime.soa.test/pom.xml 2012-04-04 13:39:36 UTC (rev 40034)
@@ -15,17 +15,4 @@
<properties>
<systemProperties>-Djbosstools.test.jboss.home.4.2=${requirement.build.root}/jboss-4.2.3.GA -Djbosstools.test.jboss.home.5.1=${requirement.build.root}/jboss-5.1.0.GA -Djbosstools.test.seam.2.0.1.GA.home=${requirement.build.root}/jboss-seam-2.0.1.GA -Djbosstools.test.seam.2.2.0.GA.home=${requirement.build.root}/jboss-seam-2.2.0.GA -Djbosstools.test.eap.4.3.home=${requirement.build.root}/jboss-eap-4.3 -Dskip.runtime.scanner=true -Djbosstools.test.jboss.home.7.0=${requirement.build.root}/jboss-7.0.0.Beta3</systemProperties>
</properties>
- <build>
- <plugins>
- <plugin>
- <groupId>org.eclipse.tycho</groupId>
- <artifactId>tycho-surefire-plugin</artifactId>
- <version>${tychoVersion}</version>
- <configuration>
- <testSuite>org.jboss.tools.runtime.test</testSuite>
- <testClass>org.jboss.tools.runtime.test.RuntimeDetectionAllTests</testClass>
- </configuration>
- </plugin>
- </plugins>
- </build>
</project>
14 years
JBoss Tools SVN: r40033 - trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details.
by jbosstools-commits@lists.jboss.org
Author: dgeraskov
Date: 2012-04-04 09:21:43 -0400 (Wed, 04 Apr 2012)
New Revision: 40033
Modified:
trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java
Log:
https://issues.jboss.org/browse/JBIDE-11161
Make hibernate.cfg path file system absolute if it is not in the project class path
Modified: trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java
===================================================================
--- trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java 2012-04-04 12:54:29 UTC (rev 40032)
+++ trunk/hibernatetools/plugins/org.jboss.tools.hibernate.jpt.ui/src/org/jboss/tools/hibernate/jpt/ui/internal/persistence/details/HibernatePropertiesComposite.java 2012-04-04 13:21:43 UTC (rev 40033)
@@ -15,11 +15,13 @@
import java.util.List;
import org.eclipse.core.resources.IContainer;
+import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.Path;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.IPackageFragmentRoot;
import org.eclipse.jdt.core.JavaCore;
@@ -41,6 +43,7 @@
import org.eclipse.jpt.common.utility.model.listener.PropertyChangeListener;
import org.eclipse.jpt.common.utility.model.value.PropertyValueModel;
import org.eclipse.jpt.common.utility.model.value.WritablePropertyValueModel;
+import org.eclipse.jpt.jpa.core.JpaProject;
import org.eclipse.jpt.jpa.ui.details.JpaPageComposite;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Button;
@@ -192,6 +195,13 @@
private IPath getConfigurationFilePath() {
BasicHibernateProperties props = getSubject();
String filePath = cfgFile.getText().trim();
+ IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
+ IFile[] files = root.findFilesForLocation(new Path(filePath));
+ IPath path = null;
+ if (files != null && files.length > 0){
+ path = new Path(files[0].getProject().getName()).append(files[0].getProjectRelativePath());
+ filePath = path.toString();
+ }
if (props != null && filePath.length() > 0 ){
IProject project = props.getJpaProject().getProject();
IJavaProject jProject = JavaCore.create(project);
@@ -214,7 +224,7 @@
}
}
}
- return null;
+ return path;
}
private Runnable createSetupAction() {
@@ -243,7 +253,8 @@
IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
IResource res = root.findMember(cfgFile);
if ( res != null && res.exists() && res.getType() == IResource.FILE) {
- IProject project = res.getProject();
+ JpaProject jpaProject = HibernatePropertiesComposite.this.getSubject().getJpaProject();
+ IProject project = jpaProject.getProject();
IJavaProject jProject = JavaCore.create(project);
if (jProject != null){
try {
@@ -252,7 +263,7 @@
if (!iPackageFragmentRoot.isArchive()){
if (iPackageFragmentRoot.getResource().getFullPath().isPrefixOf(cfgFile)){
cfgFile = cfgFile.removeFirstSegments(iPackageFragmentRoot.getResource().getFullPath().segmentCount());
- return cfgFile.makeAbsolute();
+ return cfgFile;
}
}
}
@@ -261,7 +272,7 @@
}
}
}
- return cfgFile;
+ return res.getLocation();
}
private MessageDialog createSetupDialog(String title, String question, int defaultChoice){
14 years
JBoss Tools SVN: r40032 - trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test.
by jbosstools-commits@lists.jboss.org
Author: sbunciak
Date: 2012-04-04 08:54:29 -0400 (Wed, 04 Apr 2012)
New Revision: 40032
Modified:
trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/OpenShiftBotTestsMaven.launch
trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/pom.xml
Log:
Added AS dependency
Modified: trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/OpenShiftBotTestsMaven.launch
===================================================================
--- trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/OpenShiftBotTestsMaven.launch 2012-04-04 11:23:08 UTC (rev 40031)
+++ trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/OpenShiftBotTestsMaven.launch 2012-04-04 12:54:29 UTC (rev 40032)
@@ -1,13 +1,13 @@
<?xml version="1.0" encoding="UTF-8" standalone="no"?>
<launchConfiguration type="org.eclipse.m2e.Maven2LaunchConfigurationType">
<booleanAttribute key="M2_DEBUG_OUTPUT" value="false"/>
-<stringAttribute key="M2_GOALS" value="clean install -P jbosstools-nightly-staging-composite"/>
+<stringAttribute key="M2_GOALS" value="clean install"/>
<booleanAttribute key="M2_NON_RECURSIVE" value="false"/>
<booleanAttribute key="M2_OFFLINE" value="false"/>
-<stringAttribute key="M2_PROFILES" value=""/>
+<stringAttribute key="M2_PROFILES" value="default"/>
<listAttribute key="M2_PROPERTIES">
<listEntry value="swtbot.test.skip=false"/>
-<listEntry value="configurations.dir=/home/sbunciak/"/>
+<listEntry value="configurations.dir=${project_loc}/resources"/>
</listAttribute>
<stringAttribute key="M2_RUNTIME" value="EMBEDDED"/>
<booleanAttribute key="M2_SKIP_TESTS" value="false"/>
Modified: trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/pom.xml
===================================================================
--- trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/pom.xml 2012-04-04 11:23:08 UTC (rev 40031)
+++ trunk/openshift/tests/org.jboss.tools.openshift.ui.bot.test/pom.xml 2012-04-04 12:54:29 UTC (rev 40032)
@@ -36,6 +36,11 @@
<artifactId>org.jboss.tools.openshift.express.feature.feature.group</artifactId>
<version>2.3.0</version>
</dependency>
+ <dependency>
+ <type>p2-installable-unit</type>
+ <artifactId>org.jboss.tools.as.feature.feature.group</artifactId>
+ <version>2.3.0</version>
+ </dependency>
</dependencies>
</configuration>
</plugin>
14 years
JBoss Tools SVN: r40031 - trunk/cdi/tests/org.jboss.tools.cdi.seam3.bot.test/src/org/jboss/tools/cdi/seam3/bot/test/tests.
by jbosstools-commits@lists.jboss.org
Author: jjankovi
Date: 2012-04-04 07:23:08 -0400 (Wed, 04 Apr 2012)
New Revision: 40031
Modified:
trunk/cdi/tests/org.jboss.tools.cdi.seam3.bot.test/src/org/jboss/tools/cdi/seam3/bot/test/tests/DefaultBeansTest.java
Log:
Fixing to use extended version of AllAssignableDialog
Modified: trunk/cdi/tests/org.jboss.tools.cdi.seam3.bot.test/src/org/jboss/tools/cdi/seam3/bot/test/tests/DefaultBeansTest.java
===================================================================
--- trunk/cdi/tests/org.jboss.tools.cdi.seam3.bot.test/src/org/jboss/tools/cdi/seam3/bot/test/tests/DefaultBeansTest.java 2012-04-04 11:22:09 UTC (rev 40030)
+++ trunk/cdi/tests/org.jboss.tools.cdi.seam3.bot.test/src/org/jboss/tools/cdi/seam3/bot/test/tests/DefaultBeansTest.java 2012-04-04 11:23:08 UTC (rev 40031)
@@ -11,7 +11,8 @@
package org.jboss.tools.cdi.seam3.bot.test.tests;
-import org.eclipse.swtbot.swt.finder.widgets.SWTBotTable;
+import java.util.List;
+
import org.jboss.tools.cdi.bot.test.CDIConstants;
import org.jboss.tools.cdi.seam3.bot.test.base.SolderAnnotationTestBase;
import org.jboss.tools.cdi.seam3.bot.test.uiutils.AssignableBeansDialogExt;
@@ -58,15 +59,15 @@
AssignableBeansDialogExt assignDialog = new AssignableBeansDialogExt(bot.shell("Assignable Beans"));
- SWTBotTable allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 2);
+ List<String> allBeans = assignDialog.getAllBeans();
+ assertTrue(allBeans.size() == 2);
assignDialog.hideUnavailableBeans();
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
+ assertTrue(allBeans.size() == 1);
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
- assertTrue(allBeans.getTableItem(0).getText().contains("DefaultOne"));
+ assertTrue(allBeans.size() == 1);
+ assertTrue(allBeans.get(0).contains("DefaultOne"));
openOnUtil.openOnByOption("managerImpl", className, CDIConstants.OPEN_INJECT_BEAN);
String destinationFile = getEd().getTitle();
@@ -88,15 +89,15 @@
AssignableBeansDialogExt assignDialog = new AssignableBeansDialogExt(bot.shell("Assignable Beans"));
- SWTBotTable allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 2);
+ List<String> allBeans = assignDialog.getAllBeans();
+ assertTrue(allBeans.size() == 2);
assignDialog.hideDefaultBeans();
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
+ assertTrue(allBeans.size() == 1);
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
- assertTrue(allBeans.getTableItem(0).getText().contains("ManagerImpl"));
+ assertTrue(allBeans.size() == 1);
+ assertTrue(allBeans.get(0).contains("ManagerImpl"));
openOnUtil.openOnByOption("managerImpl", className, CDIConstants.OPEN_INJECT_BEAN);
String destinationFile = getEd().getTitle();
@@ -118,18 +119,18 @@
AssignableBeansDialogExt assignDialog = new AssignableBeansDialogExt(bot.shell("Assignable Beans"));
- SWTBotTable allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 2);
+ List<String> allBeans = assignDialog.getAllBeans();
+ assertTrue(allBeans.size() == 2);
assignDialog.hideDefaultBeans();
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
+ assertTrue(allBeans.size() == 1);
assignDialog.showDefaultBeans();
assignDialog.hideAmbiguousBeans();
- assertTrue(allBeans.rowCount() == 1);
+ assertTrue(allBeans.size() == 1);
allBeans = assignDialog.getAllBeans();
- assertTrue(allBeans.rowCount() == 1);
- assertTrue(allBeans.getTableItem(0).getText().contains("ManagerImpl"));
+ assertTrue(allBeans.size() == 1);
+ assertTrue(allBeans.get(0).contains("ManagerImpl"));
openOnUtil.openOnByOption("managerImpl", className, CDIConstants.OPEN_INJECT_BEAN);
String destinationFile = getEd().getTitle();
14 years
--- trunk/esb/tests/org.jboss.tools.esb.ui.bot.test/src/org/jboss/tools/esb/ui/bot/tests/examples/SimpleEAPTest.java 2012-04-04 16:11:17 UTC (rev 40039)
+++ trunk/esb/tests/org.jboss.tools.esb.ui.bot.test/src/org/jboss/tools/esb/ui/bot/tests/examples/SimpleEAPTest.java 2012-04-04 18:13:23 UTC (rev 40040)
@@ -18,6 +18,8 @@
import org.jboss.tools.ui.bot.ext.gen.ActionItem.NewObject.ESBESBProject;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.NewObject.SeamSeamWebProject;
import org.jboss.tools.ui.bot.ext.gen.ActionItem.NewObject.WebDynamicWebProject;
+import org.jboss.tools.ui.bot.ext.gen.ActionItem.Preference.RunDebugConsole;
+import org.jboss.tools.ui.bot.ext.gen.ActionItem.View.GeneralConsole;
import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotEditor;
import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotView;
@@ -65,8 +67,24 @@
public class SimpleEAPTest extends EAPExampleTest {
public static String baseDir = null; // "/opt/local/EAP6_ER41";
+ public static String projectName = "DynWebProject";
+ public static String projectDeployedText = "DynWebProject [Started, Synchronized]";
+ public static String serverName = "EAP-6.0";
Hashtable<String, Integer> portTable = new Hashtable<String, Integer>();
+ public boolean isTheAppDeployed (SWTBotTreeItem theItems[], String nameToMatch) {
+ boolean retValue = false;
+ for (SWTBotTreeItem i : theItems) {
+ System.out.println (i.getText() + "[" + projectDeployedText + "]");
+ if (i.getText().equals(nameToMatch)) {
+ retValue = true;
+ }
+ }
+ return retValue;
+ }
+
+
+
@Override
public String getExampleName() {
return "Helloworld";
@@ -77,28 +95,28 @@
}
@Override
protected void executeExample() {
-
+
/* Ports referenced in the server's config */
portTable.put("Web", 8080);
portTable.put("Management", 9999);
- // 1) Open recent JBoss Tools
- // 2) open servers view (window -> show view -> other -> Servers)
- // 3) create new server
- // - type: JBoss Community -> JBoss AS 6.0
- // - use default configuration
- // - finish wizard
- // 8) Start server, verify when server is up and running, the servers view says "Started" and not "Starting"
+ /* Test steps handled in constructor:
+ 1) Open recent JBoss Tools
+ 2) open servers view (window -> show view -> other -> Servers)
+ 3) create new server
+ - type: JBoss Community -> JBoss AS 6.0
+ - use default configuration
+ - finish wizard
+ 8) Start server, verify when server is up and running, the servers view says "Started" and not "Starting" */
- // 4) double-click server in servers view to open the server editor
+ /* Test step: 4) double-click server in servers view to open the server editor */
SWTBotView theSWTBotView = open.viewOpen(ServerServers.LABEL);
SWTBotTree serverTree = bot.tree(0);
ServersView theServerView = new ServersView();
- SWTBotTreeItem theServer = theServerView.findServerByName(serverTree, "EAP-6.0");
- //System.out.println ("*** the server = " + theServer.getText());
+ SWTBotTreeItem theServer = theServerView.findServerByName(serverTree, serverName);
assertTrue("Found the EAP 6.0 server - and the name is correct: ", theServer.getText().equals("EAP-6.0 [Started, Synchronized]"));
- // 5) in editor, verify all server ports are accurate (JNDI / Web / JMX RMI) (right side of editor)
+ /* Test step: 5) in editor, verify all server ports are accurate (JNDI / Web / JMX RMI) (right side of editor) */
theServer.doubleClick();
Enumeration<String> ePortKeys = portTable.keys();
while (ePortKeys.hasMoreElements()) {
@@ -106,12 +124,13 @@
assertTrue("The " + tempStr + " port should be " + portTable.get(tempStr), bot.textWithLabel(tempStr).getText().equals(portTable.get(tempStr).toString()));
}
- //6) click "open launch configuration" in the editor, verify launch configuration arguments and vm args match with what is expected
- // a) *** If there are any new arguments that have changed since the previous AS version, MAKE SURE the launch configuration HAS them!
+ /* Test steps:
+ 6) click "open launch configuration" in the editor, verify launch configuration arguments and vm args match with what is expected
+ a) *** If there are any new arguments that have changed since the previous AS version, MAKE SURE the launch configuration HAS them! */
bot.hyperlink("Open launch configuration").click();
- bot.sleep(3000l);
-
+ bot.sleep(Timing.time3S());
+
String tempStr1 = bot.textInGroup("Working directory:", 1).getText();
int binStr = tempStr1.indexOf("/jboss-eap-6.0/bin");
String baseDir = tempStr1.substring(0, binStr);
@@ -135,16 +154,13 @@
"\"-Dlogging.configuration=file:" + baseDir + "/jboss-eap-6.0/standalone/configuration/logging.properties\" " +
"\"-Djboss.home.dir=" + baseDir + "/jboss-eap-6.0\" "));
- org.jboss.tools.ui.bot.ext.SWTUtilExt.displayAllBotWidgets(bot);
- //bot.sleep(30000l);
bot.button("Cancel").click();
- // 7) In servers view, expand the server and look at XML Configuration/Ports, verify all labels have a number next to them
+ /* Test step - 7) In servers view, expand the server and look at XML Configuration/Ports, verify all labels have a number next to them */
theSWTBotView = open.viewOpen(ServerServers.LABEL);
serverTree = bot.tree(0);
theServerView = new ServersView();
- theServer = theServerView.findServerByName(serverTree, "EAP-6.0");
-
+ theServer = theServerView.findServerByName(serverTree, serverName);
theServer.expand();
SWTBotTreeItem thePorts = theServer.expandNode("XML Configuration").getNode("Ports");
ePortKeys = portTable.keys();
@@ -153,23 +169,62 @@
assertTrue("The " + tempStr + " port should be " + portTable.get(tempStr), bot.textWithLabel(tempStr).getText().equals(portTable.get(tempStr).toString()));
}
- // 9) Create a project (seam or dynamic web is fine, seam project is better)
+ /* Test step - 9) Create a project (seam or dynamic web is fine, seam project is better) */
theSWTBotView = open.viewOpen(ActionItem.View.GeneralNavigator.LABEL);
SWTBot wiz = open.newObject(ActionItem.NewObject.WebDynamicWebProject.LABEL);
- wiz.textWithLabel(WebDynamicWebProject.TEXT_PROJECT_NAME).setText("DynWebProject");
+ wiz.textWithLabel(WebDynamicWebProject.TEXT_PROJECT_NAME).setText(projectName);
wiz.button(IDELabel.Button.NEXT).click();
wiz.button(IDELabel.Button.NEXT).click();
wiz.button("Finish").click();
- wiz.sleep(30000l);
+ bot.sleep(Timing.time10S());
bot.button("No").click();
-// 10) Deploy it to the server, Verify the deployment works
+ /* Test step - 10) Deploy it to the server, Verify the deployment works */
+ theSWTBotView = open.viewOpen(ServerServers.LABEL);
+ serverTree = theSWTBotView.bot().tree(0);
+ theServerView = new ServersView();
+
+ theServerView.findServerByName(serverTree, serverName).contextMenu("Add and Remove...").click();
+ SWTBotTree appTree = bot.tree(0);
+ appTree.getTreeItem(projectName).select();
+ bot.button ("Add >").click();
+ bot.sleep(Timing.time3S());
+ /* There should only be one project deployed to the server */
+ assertTrue (bot.tree(1).getAllItems().length == 1);
+ assertTrue (projectName.equals(bot.tree(1).getTreeItem(projectName).getText()));
+ bot.button("Finish").click();
+ bot.sleep(Timing.time10S());
+ theSWTBotView = open.viewOpen(ServerServers.LABEL);
+ serverTree = theSWTBotView.bot().tree(0);
+ theServerView = new ServersView();
+ theServer = theServerView.findServerByName(serverTree, serverName);
+ //SWTBotTreeItem [] theItems = theServer.getItems();
+ assertTrue (isTheAppDeployed(theServer.getItems(), projectDeployedText));
-// 11) remove deployment, verify console shows deployment removed
+ theSWTBotView = open.viewOpen(ServerServers.LABEL);
+ serverTree = theSWTBotView.bot().tree(0);
+ theServerView = new ServersView();
+ theServerView.findServerByName(serverTree, serverName).contextMenu("Add and Remove...").click();
+
+ /* There should only be one project deployed to the server */
+ assertTrue (bot.tree(1).getAllItems().length == 1);
+ assertTrue (projectName.equals(bot.tree(1).getTreeItem(projectName).getText()));
+ bot.button("Finish").click();
+
+ /* Test step - 11) remove deployment, verify console shows deployment removed */
+ SWTTestExt.servers.removeAllProjectsFromServer();
+ theServerView.findServerByName(serverTree, serverName).contextMenu("Add and Remove...").click();
+ SWTBotTree deployedAppTree = bot.tree(1);
+
+ /* There should only no projects deployed to the server */
+ assertFalse (isTheAppDeployed(theServer.getItems(), projectDeployedText));
+ assertTrue (deployedAppTree.getAllItems().length == 0);
+ bot.button("Finish").click();
+
// 12) Open MBean Viewer,
// a) note that the server can now be expanded,
// b) under it are mbeans. browse down to jboss.deployment -> URL ->DeploymentScanner,
@@ -179,7 +234,7 @@
// 14) use mbean viewer / editor to execute start() operation on DeploymentScaner
// 15) verify console now accepts deployment
- bot.sleep(10000l);
+ bot.sleep(Timing.time10S());
System.out.println("***End");
SWTTestExt.servers.removeAllProjectsFromServer();
@@ -187,6 +242,4 @@
}
}
-
-
//org.jboss.tools.ui.bot.ext.SWTUtilExt.displayAllBotWidgets(bot);
\ No newline at end of file
14 years
JBoss Tools SVN: r40039 - in trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui: src/org/jboss/tools/modeshape/jcr/ui and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: elvisisking
Date: 2012-04-04 12:11:17 -0400 (Wed, 04 Apr 2012)
New Revision: 40039
Added:
trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/icons/open-declaring-node-type-16x.gif
Modified:
trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/JcrUiConstants.java
trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndFormsEditorPage.java
trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/CndMessages.java
trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/cnd/cndMessages.properties
Log:
JBIDE-10702 Editor for JCR Compact Node Definition (CND) files. Added an action to the properties table and to the child nodes table that opens (selects) the selected item definition's declaring node type in the editor.
Added: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/icons/open-declaring-node-type-16x.gif
===================================================================
(Binary files differ)
Property changes on: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/icons/open-declaring-node-type-16x.gif
___________________________________________________________________
Added: svn:mime-type
+ application/octet-stream
Modified: trunk/modeshape/plugins/org.jboss.tools.modeshape.jcr.ui/src/org/jboss/tools/modeshape/jcr/ui/JcrUiConstants.java
===================================================================